Learn R Programming

ANOM (version 0.4.2)

ANOMgen: Generic Function for Drawing ANOM Decision Charts

Description

Graphical representation of the analysis of means: convert simultaneous confidence intervals (that were computed with ANY method) into ANOM decision limits and draw a decision chart as commonly used in technometrics.

Usage

ANOMgen(mu, n=NULL, gm=NULL, lo, up, names, alternative="two.sided",
        xlabel="Group", ylabel="Endpoint", printn=T, p=NULL, bg="white")

Arguments

mu
A numeric vector of group means.
n
A numeric vector of sample sizes per group. Either n or gm must be provided.
gm
A single numeric value giving the grand mean of all groups. Either n or gm must be provided.
lo
A numeric vector of lower (simultaneous) confidence interval bounds for comparisons to the grand mean.
up
A numeric vector of upper (simultaneous) confidence interval bounds for comparisons to the grand mean.
names
An (optional) vector of characters specifying the groups' names.
alternative
A character string indicating the direction of the alternative hypothesis. Default is "two.sided", but may be changed to one-sided alternatives (either "greater" or "less").
xlabel
A character string specifying the label of the horizontal axis.
ylabel
A character string specifying the label of the vertical axis.
printn
A logical. Should per-group sample sizes be included in the chart? Default is TRUE. If n ist left at NULL, the function automatically sets printn to FALSE.
p
An (optional) numeric vector of (simultaneous) p-values to be printed.
bg
A character string. Should the plot's background be "white" (default) or "gray" (or "grey")?

Value

  • An ANOM decision chart.

Details

This is a generic tool that translates (simultaneous) confidence intervals into ANOM decision limits.

References

Pallmann, P. and Hothorn, L. A. (2015) Analysis of means (ANOM): A generalized approach using R. To appear in Journal of Applied Statistics.

Examples

Run this code
### A toy example (n given, two-sided)
groupmeans <- c(2.8, 2.3, 3.4, 5.6)
samplesizes <- c(5, 5, 10, 5)
low <- c(-1.2, -1.7, -0.4, 1.6)
upp <- c(-0.2, -0.7, 0.2, 2.6)
names <- c("1st", "2nd", "3rd", "4th")
ANOMgen(mu=groupmeans, n=samplesizes, lo=low, up=upp, names=names, alternative="two.sided")

### Another toy example (gm given, one-sided, with p-values)
groupmeans <- c(2.8, 2.3, 3.4, 5.6)
gm <- 3.5
low <- rep(-Inf, 4)
upp <- c(-0.2, -0.7, 0.2, 2.6)
names <- c("1st", "2nd", "3rd", "4th")
pvalues <- c(0.01, 0.003, 0.8, 1)
ANOMgen(mu=groupmeans, gm=gm, lo=low, up=upp, names=names, alternative="less", p=pvalues)

Run the code above in your browser using DataLab